%global momorel 1

# Reflects the values hard-coded in various Makefile.am's in the source tree.
%global dictdir %{_datadir}/cracklib
%global dictpath %{dictdir}/pw_dict

Summary: A password-checking library
Name: cracklib
Version: 2.9.6
Release: %{momorel}m%{?dist}
Group: System Environment/Libraries
Source0: https://github.com/cracklib/cracklib/releases/download/cracklib-%{version}/cracklib-%{version}.tar.gz
Source1: https://github.com/cracklib/cracklib/releases/download/cracklib-%{version}/cracklib-words-%{version}.gz
NoSource: 0
NoSource: 1

# For man pages.
Source2: http://ftp.us.debian.org/debian/pool/main/c/cracklib2/cracklib2_2.8.19-3.debian.tar.gz
NoSource: 2

# From attachment to https://bugzilla.redhat.com/show_bug.cgi?id=627449
Source3: cracklib.default.zh_CN.po

# No upstream source for this, just words missing from the current cracklib-words
Source10: missing-words.gz

Patch1: cracklib-2.9.1-inttypes.patch
Patch2: cracklib-2.9.0-python-gzdicts.patch
Patch4: cracklib-2.9.6-packlib-reentrant.patch
Patch6: cracklib-2.9.6-simplistic.patch
Patch7: cracklib-2.9.6-translation-updates.patch
Patch8: cracklib-2.9.6-cve-2016-6318.patch
URL: http://sourceforge.net/projects/cracklib/
License: LGPLv2+
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: python-devel >= 2.7, words, autoconf, automake, gettext, libtool
BuildRequires: gettext-devel, git
Conflicts: cracklib-dicts < 2.8
# The cracklib-format script calls gzip, but without a specific path.
Requires: gzip

%description
CrackLib tests passwords to determine whether they match certain
security-oriented characteristics, with the purpose of stopping users
from choosing passwords that are easy to guess. CrackLib performs
several tests on passwords: it tries to generate words from a username
and gecos entry and checks those words against the password; it checks
for simplistic patterns in passwords; and it checks for the password
in a dictionary.

CrackLib is actually a library containing a particular C function
which is used to check the password, as well as other C
functions. CrackLib is not a replacement for a passwd program; it must
be used in conjunction with an existing passwd program.

Install the cracklib package if you need a program to check users'
passwords to see if they are at least minimally secure. If you install
CrackLib, you will also want to install the cracklib-dicts package.

%package devel
Summary: Development files needed for building applications which use cracklib
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel
The cracklib-devel package contains the header files and libraries needed
for compiling applications which use cracklib.

%package -n python2-cracklib
Summary: Python bindings for applications which use cracklib
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Provides: %{name}-python = %{version}-%{release}
Provides: %{name}-python%{?_isa} = %{version}-%{release}
Obsoletes: %{name}-python < %{version}-%{release}

%description -n python2-cracklib
The cracklib-python package contains a module which permits applications
written in the Python programming language to use cracklib.

%package dicts
Summary: The standard CrackLib dictionaries
Group: System Environment/Libraries
Requires: %{name} = %{version}-%{release}
BuildRequires: words >= 2-13

%description dicts
The cracklib-dicts package includes the CrackLib dictionaries.
CrackLib will need to use the dictionary appropriate to your system,
which is normally put in /usr/share/dict/words. Cracklib-dicts also
contains the utilities necessary for the creation of new dictionaries.

If you are installing CrackLib, you should also install cracklib-dicts.

%prep
%setup -q -a 2

# Replace zn_CN.po with one that wasn't mis-transcoded at some point.
grep '????????????????' po/zh_CN.po
install -p -m 644 %{SOURCE3} po/zh_CN.po

%patch1 -p1 -b .inttypes
%patch2 -p1 -b .gzdicts
%patch4 -p1 -b .reentrant
%patch6 -p1 -b .simplistic
%patch7 -p1 -b .translations
%patch8 -p1 -b .overflow

mkdir cracklib-dicts
for dict in %{SOURCE10} %{SOURCE1}
do
        cp -fv ${dict} cracklib-dicts/
done
chmod +x util/cracklib-format

%build
%configure --with-pic --with-python --with-default-dict=%{dictpath} --disable-static
make -C po update-gmo
make

%install
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT 'pythondir=${pyexecdir}'
./util/cracklib-format cracklib-dicts/* | \
./util/cracklib-packer $RPM_BUILD_ROOT/%{dictpath}
./util/cracklib-format $RPM_BUILD_ROOT/%{dictdir}/cracklib-small | \
./util/cracklib-packer $RPM_BUILD_ROOT/%{dictdir}/cracklib-small
rm -f $RPM_BUILD_ROOT/%{dictdir}/cracklib-small
sed s,/usr/lib/cracklib_dict,%{dictpath},g lib/crack.h > $RPM_BUILD_ROOT/%{_includedir}/crack.h
ln -s cracklib-format $RPM_BUILD_ROOT/%{_sbindir}/mkdict
ln -s cracklib-packer $RPM_BUILD_ROOT/%{_sbindir}/packer
touch $RPM_BUILD_ROOT/top

toprelpath=..
touch $RPM_BUILD_ROOT/top
while ! test -f $RPM_BUILD_ROOT/%{_libdir}/$toprelpath/top ; do
        toprelpath=../$toprelpath
done
rm -f $RPM_BUILD_ROOT/top
if test %{dictpath} != %{_libdir}/cracklib_dict ; then
ln -s $toprelpath%{dictpath}.hwm $RPM_BUILD_ROOT/%{_libdir}/cracklib_dict.hwm
ln -s $toprelpath%{dictpath}.pwd $RPM_BUILD_ROOT/%{_libdir}/cracklib_dict.pwd
ln -s $toprelpath%{dictpath}.pwi $RPM_BUILD_ROOT/%{_libdir}/cracklib_dict.pwi
fi
rm -f $RPM_BUILD_ROOT/%{_libdir}/python*/site-packages/_cracklib*.*a
rm -f $RPM_BUILD_ROOT/%{_libdir}/libcrack.la
mkdir -p $RPM_BUILD_ROOT/%{_mandir}/man{3,8}
install -p -m644 debian/*.3 $RPM_BUILD_ROOT/%{_mandir}/man3/
install -p -m644 debian/*.8 $RPM_BUILD_ROOT/%{_mandir}/man8/
if ! test -s $RPM_BUILD_ROOT/%{_mandir}/man8/cracklib-packer.8 ; then
    echo .so man8/cracklib-format.8 > $RPM_BUILD_ROOT/%{_mandir}/man8/cracklib-packer.8
fi
if ! test -s $RPM_BUILD_ROOT/%{_mandir}/man8/cracklib-unpacker.8 ; then
    echo .so man8/cracklib-format.8 > $RPM_BUILD_ROOT/%{_mandir}/man8/cracklib-unpacker.8
fi

%find_lang %{name}

%check
make test
# We want to check that the new library is able to open the new dictionaries,
# using the new python module.
LD_LIBRARY_PATH=$RPM_BUILD_ROOT/%{_libdir} %{__python} 2>&1 << EOF
import string, sys
# Prepend buildroot-specific variations of the python path to the python path.
syspath2=[]
for element in sys.path:
        syspath2.append("$RPM_BUILD_ROOT/" + element)
syspath2.reverse()
for element in syspath2:
        sys.path.insert(0,element)
# Now actually do the test.  If we get a different result, or throw an
# exception, the script will end with the error.
import cracklib
try:
        s = cracklib.FascistCheck("cracklib", "$RPM_BUILD_ROOT/%{dictpath}")
except ValueError, message:
        expected = "it is based on a dictionary word"
        if message != expected:
                print "Got unexpected result \"%s\"," % messgae,
                print "instead of expected value of \"%s\"." % expected
                sys.exit(1)
        print "Got expected result \"%s\"," % message
        sys.exit(0)
finally:
        sys.exit(0)
EOF

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%triggerpostun -p /sbin/ldconfig -- cracklib < 2.7-24

%files -f %{name}.lang
%defattr(-,root,root)
%doc README README-WORDS NEWS README-LICENSE AUTHORS COPYING.LIB
%{_libdir}/libcrack.so.*
%dir %{_datadir}/cracklib
%{_datadir}/cracklib/cracklib.magic
%{_sbindir}/*cracklib*
%{_mandir}/man8/*

%files devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/libcrack.so
%{_mandir}/man3/*

%files dicts
%defattr(-,root,root)
%{_datadir}/cracklib/pw_dict.*
%{_datadir}/cracklib/cracklib-small.*
%{_libdir}/cracklib_dict.*
%{_sbindir}/mkdict
%{_sbindir}/packer

%files -n python2-cracklib
%defattr(-,root,root)
%{_libdir}/python*/site-packages/_cracklib*.so
%{_libdir}/python*/site-packages/*.py*

%changelog
* Tue Jan 16 2018 Yohsuke Ooi <meke@momonga-linux.org>
- (2.9.6-1m)
- update 2.9.6

* Thu Apr 28 2011 Yohsuke Ooi <meke@momonga-linux.org> 
- (2.8.18-1m)
- update 2.8.18

* Mon Apr 11 2011 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (2.8.16-5m)
- rebuild for new GCC 4.6

* Sun Nov 28 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (2.8.16-4m)
- rebuild for new GCC 4.5

* Tue Oct 26 2010 Mitsuru SHIMAMURA <smbd@momonga-linux.org>
- (2.8.16-3m)
- add git to BuildRequires

* Tue Aug 31 2010 Yohsuke Ooi <meke@momonga-linux.org>
- (2.8.16-2m)
- full rebuild for mo7 release

* Sun Jul 18 2010 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (2.8.16-1m)
- sync with Rawhide (2.8.16-3)
- add REMOVE.PLEASE to pass %%check
-- if cracklib < 2.8.14 is installed, then an error
-- "_cracklibmodule.so: undefined symbol: GetDefaultCracklibDict"
-- may occur. this symbol was introduced in 2.8.14.

* Sat Apr 24 2010 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.8.13-3m)
- use BuildRequires

* Sat Nov 14 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (2.8.13-2m)
- rebuild against gcc-4.4 and glibc-2.11

* Mon Feb 23 2009 Yohsuke Ooi <meke@momonga-linux.org> 
- (2.8.13-1m)
- update 2.8.13

* Wed Jan 21 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (2.8.9-6m)
- rebuild against rpm-4.6

* Thu Jan  1 2009 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (1.0.5-2m)
- rebuild against python-2.6.1-2m

* Thu Apr 03 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.8.9-4m)
- rebuild against gcc43

* Thu Feb 14 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (2.8.9-3m)
- %%NoSource -> NoSource

* Wed Mar 28 2007 Mitsuru Shimamura <smbd@momonga-linux.org>
- (2.8.9-2m)
- roll back to 2.8.9

* Thu Mar 22 2007 Mitsuru Shimamura <smbd@momonga-linux.org>
- (2.8.10-1m)
- up to 2.8.10

* Sat Dec 23 2006 Yohsuke Ooi <meke@momonga-linux.org>
- (2.8.9-1m)
- update 2.8.9

* Sun Jun 11 2006 Ichiro Nakai <ichiro@n.email.ne.jp>
- (2.8.6-2m)
- revise %%files

* Thu May 11 2006 Masahiro Takahata <takahata@momonga-linux.org>
- (2.8.6-1m)
- version up

* Wed Jan 11 2006 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.8.3-2m)
- add BuildRequires: gcc-c++ for cpp check fail

* Mon Aug  1 2005 Yohsuke Ooi  <meke@momonga-linux.org>
- (2.8.3-1m)
- sync FC-devel

- revised docdir permission
* Sat Feb 19 2005 Ryu SASAOKA <ryu@momonga-linux.org>
- (2.7-20m)
- revised docdir permission

* Fri Jan 14 2005 Toru Hoshina <t@momonga-linux.org>
- (2.7-19m)
- enable x86_64.

* Fri May 14 2004 Masahiro Takahata <takahata@momonga-linux.org>
- (2.7-18m)
- change URI

* Thu Oct  9 2003 Ryu SASAOKA <ryu@momonga-linux.org>
- (2.7-17m)
- adapt the License: preamble for the Momonga Linux license
  expression unification policy (draft)

* Mon Mar 03 2003 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.7-16m)
- change Source URI

* Sat Oct 26 2002 YAMAZAKI Makoto <uomaster@nifty.com>
- (2.7-15m)
- sync with redhat-8.0(cracklib-2.7-18)
- remove -fstack-protector(because of build failure...)

* Wed May 22 2002 Masaru Sato <masachan@kondara.org>
- (2.7-14k)
- Fix Makefile, install /usr/include/packer.h

* Fri Jan 18 2002 Kazuhiko <kazuhiko@kondara.org>
- (2.7-12k)
- obey fhs
- add BuildPreReq

* Wed Apr  4 2001 Shingo Akagaki <dora@Kondara.org>
- make static lib
- make devel package

* Wed Jul 05 2000 Toru Hoshina <t@kondara.org>
- rebuild against glibc-2.1.90, X-4.0, rpm-3.0.5.

* Fri Dec 10 1999 Shingo Akagaki <dora@kondara.org>
- fix spec file

* Mon Nov 8 1999 Toru Hoshina <t@kondara.org>
- be a NoSrc :-P

* Tue Apr 06 1999 Preston Brown <pbrown@redhat.com>
- strip binaries

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 4)

* Wed Jan 06 1999 Cristian Gafton <gafton@redhat.com>
- build for glibc 2.1

* Sat May 09 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Tue Mar 10 1998 Cristian Gafton <gafton@redhat.com>
- updated to 2.7
- build shared libraries

* Mon Nov 03 1997 Donnie Barnes <djb@redhat.com>
- added -fPIC

* Mon Oct 13 1997 Donnie Barnes <djb@redhat.com>
- basic spec file cleanups

* Mon Jun 02 1997 Erik Troan <ewt@redhat.com>
- built against glibc

